===============
twigs_ssl_audit
===============


.. image:: https://img.shields.io/pypi/v/twigs_ssl_audit.svg
        :target: https://pypi.python.org/pypi/twigs_ssl_audit

.. image:: https://img.shields.io/travis/threatwatch/twigs_ssl_audit.svg
        :target: https://travis-ci.org/threatwatch/twigs_ssl_audit

.. image:: https://readthedocs.org/projects/twigs-ssl-audit/badge/?version=latest
        :target: https://twigs-ssl-audit.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




TWIGS SSL Audit


* Free software: GNU General Public License v3
* Documentation: https://twigs-ssl-audit.readthedocs.io.


Features
--------

* This is a sub-package used by twigs for performing SSL audit.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
